library(ggpubr)
library(dplyr)

#criando um banco de dados
df<-data.frame(x=c(12, 19, 25, 34, 48, 57), y = c(44, 58, 69, 78, 84, 90), pontos=c("A", "B", "C", "D", "E", "F")) 
str(df)
head(df)

model1<-lm(x~y, data = df)
summary(model1)
AIC(model1)

model_nulo<-lm(y~1, data = df)
summary(model_nulo)
AIC(model_nulo)

#fazendo um simples gráfico X e Y
xy<-ggplot(df, aes(x, y)) + 
  geom_point() + 
  theme_half_open()
xy

#Gráfico XY colorindo e variando os "shape" dos pontos conforme a variável "pontos"
xy<-ggplot(df, aes(x, y)) + 
  geom_point(aes(color = pontos, shape = pontos), size = 3) + 
  scale_color_viridis(discrete = T) +
  scale_fill_viridis(discrete = T) +
  theme_half_open()
xy

#Mudando os shapes dos pontos
shapes <- image_read('https://ggplot2.tidyverse.org/articles/ggplot2-specs_files/figure-html/unnamed-chunk-7-1.png')
print(shapes)


xy<-ggplot(df, aes(x, y)) + 
  geom_point(aes(color = pontos, shape = pontos), size = 4) + 
  scale_shape_manual(values = c(12,7,2,8,13,9)) + 
  scale_color_viridis(discrete = T, option = "C", begin= 0.25, end=0.75) +
  scale_fill_viridis(discrete = T, option = "C") +
  theme_half_open()
xy

#Traçando uma lina entre os pontos
xy<-ggplot(df, aes(x, y)) + 
  geom_point(size = 4) +
  scale_color_viridis(discrete = T, option = "C") +
  scale_fill_viridis(discrete = T, option = "C")+
  geom_smooth(color = "black") +
  #scale_shape_manual(values = c(12,7,2,8,13,9)) + 
  #scale_color_viridis(discrete = T, option = "C") +
  #scale_fill_viridis(discrete = T, option = "C") +
  theme_half_open()
xy

#Traçando uma linha de regressão
xy<-ggplot(df, aes(x, y)) + 
  geom_point(size = 4) +
  geom_smooth(method = lm, se =T, color = "black") +
  #scale_shape_manual(values = c(12,7,2,8,13,9)) + 
  scale_color_viridis(discrete = T, option = "C") +
  scale_fill_viridis(discrete = T, option = "C") +
  theme_half_open()
xy


#Ajustando uma curva usando geom_smooth
xy<-ggplot(df, aes(x, y)) + 
  geom_point(size = 4) +
  geom_smooth(method = lm, se =T, color = "black") +
  stat_cor(aes(label = paste(..rr.label.., ..p.label.., sep = "~`,`~")),
         r.accuracy = 0.01,
         p.accuracy = 0.01,
         label.x = 35, label.y = 40, size = 4) +
  stat_regline_equation(aes(label = ..eq.label..),
                        label.x = 20, label.y = 105, size = 4) +
  #scale_shape_manual(values = c(12,7,2,8,13,9)) + 
  scale_color_viridis(discrete = T, option = "C") +
  scale_fill_viridis(discrete = T, option = "C") +
  theme_half_open()
xy

#Ajustando uma curva usando geom_smoot, polinomial
xy<-ggplot(df, aes(x, y)) + 
  geom_point(size = 4) +
  geom_smooth(method = lm, formula = y ~ "splines::bs"=bs(x, 3), se =T, color = "black") +
  stat_poly_line(formula = formula, color = "black", linetype = "dashed",) +
  stat_poly_eq(aes(label = after_stat(adj.rr.label)), formula = formula) +
  stat_poly_eq(aes(label = after_stat(AIC.label)),
               label.x = "right", label.y = "bottom", size = 4,     
               formula = formula) +
  #scale_shape_manual(values = c(12,7,2,8,13,9)) + 
  scale_color_viridis(discrete = T, option = "C") +
  scale_fill_viridis(discrete = T, option = "C") +
  theme_half_open()
xy

install.packages()
library(splines2)

#É possível ajustar algumas curvas para os dados. No entanto, confesso que não dediquei muito tempo a isso. 
install.packages("ggpmisc")
library(ggpmisc)
library(quantreg)


formula<-y ~ poly(x, 3, raw = TRUE)
xy<-ggplot(df, aes(x, y)) +
  geom_point(size = 4) +
  stat_poly_line(formula = formula, color = "black", linetype = "dashed",) +
  stat_poly_eq(aes(label = after_stat(adj.rr.label)), formula = formula) +
  stat_poly_eq(aes(label = after_stat(AIC.label)),
               label.x = "right", label.y = "bottom", size = 4,     
               formula = formula) +
  scale_color_viridis(discrete = T, option = "C") +
  scale_fill_viridis(discrete = T, option = "C") +
  theme_half_open()
xy

  

#Gráficos xy na vida real. 
data<-read.csv("small_mammals_plants.csv", header=T)
head(data)
data$biome<-factor(data$biome, levels=c("Amazon", "Atlantic", "Cerrado"))
data$class<-factor(data$class, levels = c("Mammalia","C3", "C4"))
data$tissue<-factor(data$tissue,  levels = c("keratin", "leaf"))
head(data)
str(data)
biome<-factor(data$biome)
class<-factor(data$class)
tissue<-factor(data$tissue)
head(data)
biomes<-c("Amazon", "Atlantic", "Cerrado")
tissues<-c("keratin", "leaf")
classes<-c("Mammalia", "C3", "C4")
data<-filter(data, biome %in% biomes)
head(data)
data<-filter(data, tissue %in% tissues)
head(data)
data<-filter(data, class %in% classes)
head(data)
###MAMÍFEROS
biplot_mammals <- ggplot(data, aes(x = d13C, y = d15N, color = class, fill = class))   +  
          scale_y_continuous(name=expression(paste(delta^{15}, "N (\u2030)")), breaks = seq(-4, 16, 4),limits=c(-4,16)) +
          scale_x_continuous(name = expression(paste(delta^{13}, "C (\u2030)")), breaks = seq(-42, -8, 8), limits=c(-42, -8)) + 
         geom_point(aes(color=class),size=1.5, alpha=0.3) + 
         scale_color_manual(values = c("#3CBB75FF", "#DCE319FF", "#482677FF")) + 
         scale_fill_manual(values = c("#3CBB75FF", "#DCE319FF", "#482677FF")) +
         facet_wrap(~biome, nrow=3, strip.position="top") + 
        theme(axis.line.x = element_line(size = 0.5, colour = "black"),legend.title = element_blank(),legend.key = element_rect(fill = "white", color = NA), aspect.ratio = 1,
        legend.text = element_text(color = "black",size=12, face="bold"),
        legend.position = "none", legend.direction = "horizontal",                 
        axis.line.y = element_line(size = 0.5, colour = "black"),
        axis.line = element_line(size=1, colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_rect(fill=NA, linetype=1, colour="black"),
        panel.background = element_blank(),
        axis.text.x=element_text(colour="black", size = 18, face="bold"),
        axis.text.y=element_text(colour="black", size = 18, face="bold"), 
        axis.title.x = element_text(colour="black", size = 18, face = "bold"),strip.text=element_text(colour="black",size=18, face="bold"),strip.background = element_rect(fill="white", linetype=1, colour="black"),
        axis.title.y = element_text(colour="black", size = 18, face = "bold"))
biplot_mammals
ggsave("biplot_viridis_small_mammals_plants.jpeg", units="cm", width=18, height=22, dpi=600)
dev.off()


###AVES
data<-read.csv("animal_plant_biome.csv", header=T)
data$biome<-factor(data$biome, levels=c("Amazon", "Atlantic", "Cerrado"))
data$class<-factor(data$class, levels = c("C3", "C4", "Aves"))
biome<-factor(data$biome)
biomes<-c("Amazon", "Atlantic", "Cerrado")
tissues<-c("keratin", "leaf")
classes<-c("Aves", "C3", "C4")
data<-filter(data, biome %in% biomes)
data<-filter(data, tissue %in% tissues)
data<-filter(data, class %in% classes)

biplot_aves <- ggplot(data, aes(x = d13C, y = d15N, color=class, fill = class))   +  
  scale_y_continuous(name=expression(paste(delta^{15}, "N (\u2030)")), breaks = seq(-4, 16, 4),limits=c(-4,16)) +
  scale_x_continuous(name = expression(paste(delta^{13}, "C (\u2030)")), breaks = seq(-42, -8, 8), limits=c(-42, -8)) + 
  geom_point(aes(color=class),size=1.5, alpha=0.3) + 
  scale_color_manual(values = c("#3CBB75FF", "#DCE319FF", "#482677FF")) + 
  scale_fill_manual(values = c("#3CBB75FF", "#DCE319FF", "#482677FF")) +
  facet_wrap(~biome, nrow=3, strip.position="top")+ 
  theme(axis.line.x = element_line(size = 0.5, colour = "black"),legend.title = element_blank(),legend.key = element_rect(fill = "white", color = NA), aspect.ratio = 1,
        legend.text = element_text(color = "black",size=12, face="bold"),
        legend.position = "none", legend.direction = "horizontal",                 
        axis.line.y = element_line(size = 0.5, colour = "black"),
        axis.line = element_line(size=1, colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_rect(fill=NA, linetype=1, colour="black"),
        panel.background = element_blank(),
        axis.text.x=element_text(colour="black", size = 18, face="bold"),
        axis.text.y=element_text(colour="black", size = 18, face="bold"), 
        axis.title.x = element_text(colour="black", size = 18, face = "bold"),strip.text=element_text(colour="black",size=18, face="bold"),strip.background = element_rect(fill="white", linetype=1, colour="black"),
        axis.title.y = element_text(colour="black", size = 18, face = "bold"))
biplot_aves
ggsave("biplot_aves.jpeg", units="cm", width=16, height=28, dpi=600)
dev.off()



install.packages("ggpubr")
library(ggpubr)

biplot_mammals_aves<-ggarrange(biplot_aves,biplot_mammals, labels = c("A", "B"),
                            common.legend = TRUE, legend = TRUE,  ncol = 2, nrow = 1)
ggsave("biplot_mammals_aves_demo.jpeg", units="cm", width=16, height=28, dpi=600)
dev.off()

#https://cran.r-project.org/web/packages/ggpmisc/vignettes/model-based-annotations.html#stat_poly_eq-and-stat_poly_line
set.seed(4321)
# generate artificial data
x <- 1:100
y <- (x + x^2 + x^3) + rnorm(length(x), mean = 0, sd = mean(x^3) / 4)
my.data <- data.frame(x, 
                      y, 
                      group = c("A", "B"), 
                      y2 = y * c(0.5,2),
                      block = c("a", "a", "b", "b"),
                      wt = sqrt(x))
head(my.data)
ggplot(df, aes(x, y)) +
  geom_point() +
  stat_correlation()

ggplot(df, aes(x, y, color = group)) +
  geom_point() +
  stat_correlation(method = "spearman")

ggplot(my.data, aes(x, y, color = group)) +
  geom_point() +
  stat_correlation(mapping = aes(label = paste(after_stat(cor.label),
                                               after_stat(t.value.label),
                                               after_stat(p.value.label),
                                               after_stat(n.label),
                                               sep = '*"; "*')))

ggplot(my.data, aes(x, y)) +
  geom_point() +
  stat_correlation() +
  facet_wrap(~group)

ggplot(my.data, aes(x, y)) +
  geom_point() +
  stat_correlation(mapping = aes(color = ifelse(after_stat(cor) > 0.9,
                                                "red", "black"))) +
  scale_color_identity() +
  facet_wrap(~group)

set.seed(4321)
# generate artificial data
x <- 1:100
y <- (x + x^2 + x^3) + rnorm(length(x), mean = 0, sd = mean(x^3) / 4)
my.data <- data.frame(x, 
                      y, 
                      group = c("A", "B"), 
                      y2 = y * c(0.5,2),
                      block = c("a", "a", "b", "b"),
                      wt = sqrt(x))

formula <- y ~ poly(x, 3, raw = TRUE)
ggplot(my.data, aes(x, y)) +
  geom_point() +
  stat_poly_line(formula = formula) +
  stat_poly_eq(formula = formula)

formula <- y ~ poly(x, 3, raw = TRUE)
ggplot(df, aes(x, y)) +
  geom_point() +
  stat_poly_line(formula = formula) +
  stat_poly_eq(aes(label = after_stat(eq.label)), formula = formula)

xy<-ggplot(df, aes(x, y)) +
  geom_point(size = 4) +
  stat_poly_line(formula = formula, color = "black", linetype = "dashed") +
  stat_poly_eq(aes(label = after_stat(adj.rr.label)), formula = formula) +
  stat_poly_eq(aes(label = after_stat(AIC.label)),
               label.x = "right", label.y = "bottom", size = 3,     
               formula = formula) +
  scale_color_viridis(discrete = T, option = "C") +
  scale_fill_viridis(discrete = T, option = "C") +
  theme_half_open()
xy
 

formula <- y ~ poly(x, 3, raw = TRUE)
ggplot(df, aes(x, y)) +
  geom_point() +
  stat_poly_line(formula = formula) +
  stat_poly_eq(aes(label = paste("atop(", after_stat(AIC.label), ",", after_stat(BIC.label), ")", sep = "")), 
               formula = formula)
